[CRIU] [PATCH] tty: Fix hangup typos

Cyrill Gorcunov gorcunov at openvz.org
Mon Oct 29 05:18:02 EDT 2012


Reported-by: Pavel Emelyanov <xemul at parallels.com>
Signed-off-by: Cyrill Gorcunov <gorcunov at openvz.org>
---

The patch is on top of latest TTY fix series.

 tty.c |   12 ++++++------
 1 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/tty.c b/tty.c
index 9afbf30..322aa87 100644
--- a/tty.c
+++ b/tty.c
@@ -393,7 +393,7 @@ static bool pty_is_master(struct tty_info *info)
 	return info->major == TTYAUX_MAJOR;
 }
 
-static bool pty_is_hanged(struct tty_info *info)
+static bool pty_is_hangup(struct tty_info *info)
 {
 	return info->tie->sid == 0 && info->tie->termios == NULL;
 }
@@ -704,10 +704,10 @@ static int tty_find_restoring_task(struct tty_info *info)
 	}
 
 	/*
 	 * Hanged up terminals require a fake master peer.
 	 */
-	if (pty_is_hanged(info)) {
-		pr_debug("Hanged up terminal id %x\n", info->tfe->id);
+	if (pty_is_hangup(info)) {
+		pr_debug("Hangup terminal id %x\n", info->tfe->id);
 		return 0;
 	}
 
@@ -901,7 +901,7 @@ static int collect_one_tty(void *obj, ProtobufCMessage *msg)
 		return -1;
 
 	/*
 	 * The tty peers which have no @termios are hunged up,
 	 * so don't mark them as active, we create them with
 	 * faked master and they are rather a rudiment which
 	 * can't be used. Most likely they appear if a user has
@@ -1033,7 +1033,7 @@ static int dump_pty_info(int lfd, u32 id, const struct fd_parms *p, int major, i
 	pty.index		= index;
 
 	/*
 	 * Nothing we can do on hangin up terminal,
 	 * just write out minimum information we can
 	 * gather.
 	 */
@@ -704,10 +704,10 @@ static int tty_find_restoring_task(struct tty_info *info)
 
 	/*
-	 * Hanged up terminals require a fake master peer.
+	 * Hangup terminals require a fake master peer.
 	 */
@@ -901,7 +901,7 @@ static int collect_one_tty(void *obj, ProtobufCMessage *msg)
 
 	/*
-	 * The tty peers which have no @termios are hunged up,
+	 * The tty peers which have no @termios are hangup,
 	 * so don't mark them as active, we create them with
 	 * faked master and they are rather a rudiment which
@@ -1033,7 +1033,7 @@ static int dump_pty_info(int lfd, u32 id, const struct fd_parms *p, int major, i
 
 	/*
-	 * Nothing we can do on hangin up terminal,
+	 * Nothing we can do on hangup terminal,
 	 * just write out minimum information we can
 	 * gather.
-- 
1.7.7.6



More information about the CRIU mailing list